<?php

namespace Drupal\unwanted_email_registration;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\MessengerInterface;

/**
 * Class Unwanted Email Registration Service.
 */
class UnwantedEmailRegistrationService {

  /**
   * Constructs a new CustomService object.
   */
  public function __construct(ConfigFactoryInterface $config_factory, Connection $connection, MessengerInterface $messenger) {
    $this->config = $config_factory->get('unwanted_email_registration.settings');
    $this->connection = $connection;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public function validateEmail($email) {
    if (!empty($email)) {
      /* If the current and new email address are the same then we can skip this check List of allowed domains. */
      $allowed = array_map('trim', explode("\n", $this->config->get('email_domains')));

      $parts = explode('@', $email);

      $domain = array_pop($parts);

      /* Check if the domain is in our list. */
      if (!in_array($domain, $allowed)) {
        // Not allowed.
        return TRUE;
      }
      // Check to see if our domain is in the configured list.
      if (in_array($domain, $allowed)) {

        if (user_load_by_mail(filter_email($email))) {
          return FALSE;
        }

        /* Get all system emails. Do this in memory to improve speed and lessen the hit To the database . */
        $query = $this->connection->select('users_field_data', 'u')
          ->fields('u', ['mail']);
        $results = $query->execute()->fetchAllAssoc('mail');

        foreach ($results as $result) {
          $filter_email = filter_email($result->mail);
          if ($filter_email == $email || $filter_email == filter_email($email)) {

            return FALSE;

          }
        }
      }
    }
    return TRUE;
  }

}
